---
title: Sizing
summary: Overview of the sizing modules of aircraftDesign repository
authors:
    - Sebastian Oberschwendtner
    - Kristina Mazur
date: 2024-11-28
glightbox: false
---
# Sizing Tools
The sizing tools design and estimate aircraft parameters.
They mainly change the dimensions of the aircraft and systems.
The following sizing tools are available:

---

## Initial sizing
![Icon](../assets/images/documentation/initial-sizing.svg){.overview-img  align=left}
The module **initial_sizing** is used to determine a design chart regarding Top Level Aircraft Requirements and Certification Specification Requirements.
The wing-loading ($\frac{W}{S}$) and thrust to weight ratio ($\frac{T}{W}$) can be derived as the design point for further modules from the Design Chart.
Furthermore an initial estimation of the takeoff mass is done.
{.overview-item}

|Module Version|Language|License|Documentation|
|:---:|:---:|:---:|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link](initial_sizing/index.html)|

---

## Create mission XML
![Icon](../assets/images/documentation/create-mission.png){.overview-img  align=left}
The **create_mission_XML** is the third module of the UNICADO tool chain.
Its purpose is to set up the overall flight mission including e.g. a flight segment table, speed and altitude schedules, number of passengers (PAX), total payload or the engine warm up time.
For the user, possible changes in the module run configuration can be made in the related createMissionXML_conf.xml file.
The parameters comprised in this file can have different attributes as e.g. Desc, Unit, Default or #text and are further subdivided into control settings and program settings.
{.overview-item}

|Module Version|Language|License|Documentation|
|:---:|:---:|:---:|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link](create_mission_xml/index.html)|

---

## Fuselage design
![Icon](../assets/images/documentation/fuselage-design.png){.overview-img align=left}
The **fuselage_design** module calculates characteristic parameters and generates the passenger cabin and fuselage layout for the entire aircraft project.
{.overview-item}

|Module Version|Language|License|Documentation|
|:---:|:---:|:---:|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link](fuselage_design/index.html)|

---

## Wing design
![Icon](../assets/images/documentation/wing-design.svg){.overview-img  align=left}
The **wing_design** module calculates characteristic parameter of the aircraft main wing.
{.overview-item}

|Module Version|Language|License|Documentation|
|:---:|:---:|:---:|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link](wing_design/index.html)|

---

## Empennage design
![Icon](../assets/images/documentation/empennage-sizing.png){.overview-img  align=left}
The **empennage_design** module calculates characteristic parameter of the empennage of the aircraft.
It takes takes the controllability as wells as the static margin of the aircraft into account and sizes the empennage accordingly.
{.overview-item}

|Module Version|Language|License|Documentation|
|:---:|:---:|:---:|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link](empennage_design/index.html)|

---

## Tank design
![Icon](../assets/images/documentation/hydrogen-tank.svg){.overview-img  align=left}
:construction: *tbd*
{.overview-item}

|Module Version|Language|License|Documentation|
|:---:|:---:|:---:|---|
|2.1.0|:simple-python: |GPLv3|[Link](tank_design/index.html)|


---

## Propulsion design
![Icon](../assets/images/documentation/propulsion-design.svg){.overview-img  align=left}
The **propulsionDesign** module designs, integrates and analyzes the propulsion system to the aircraft.
It uses engine performance deck containing serval parameters (like thrust, fuel-flow, ...) as a function of the flight Mach number and the altitude.
The engine will be scaled by the module to match the specific thrust requirements.
Moreover, an engine bucket curve and several engine deck plots can be created.
Additionally, the propulsion is integrated in relation to the user settings (e.g. integration of the propulsion on the wing or fuselage, ...).
Depending on the location of the integration, the tool calculates the nacelle and pylon geometry.
Also the mass properties are analyzed.
{.overview-item}

|Module Version|Language|License|Documentation|
|:---:|:---:|:---:|---|
|3.0.0|:simple-cplusplus: |GPLv3|[Link](propulsion_design/content/index.md)|

---

## Landing gear design
![Icon](../assets/images/documentation/landing-gear-design.svg){.overview-img  align=left}
The **landing_gear_design** module calculates characteristic parameters for the landing gear of entire aircraft project.
{.overview-item}

|Module Version|Language|License|Documentation|
|:---:|:---:|:---:|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link](landing_gear_design/index.html)|

---

## Systems design
![Icon](../assets/images/documentation/systems-design.png){.overview-img  align=left}
The **systems_design** is part of the tool chain in the UNICADO aircraft design environment.
It dimensions ATA chapter systems in terms of mass and energy requirement divided by hydraulic- electric- and bleed air energy requirement.
{.overview-item}

|Module Version|Language|License|Documentation|
|:---:|:---:|:---:|---|
|2.1.0|:simple-cplusplus: |GPLv3|[Link](systems_design/index.html)|

---
