> :construction: Under construction. Needs to be checked for final folder structure.

You want to execute UNICADO tools separately? Here we go:

## Requirements

Ensure that you have cloned the following repositories:

- **Aircraft Design** - aircraft design tools (including the submodule `libs`)
- **Aircraft References** - aircraft reference designs
- **Engines** - engine data

If you haven't yet, don't worry: just follow [these](../developer/get-source-code.md) instructions before continuing.

Ensure, that you have checked out the same branch (e.g. `develop`) for both **Aircraft Design** and **Engines**, as they are synchronized on remote and a running couple.
For testing purposes you most probably will choose the CSMR-2020 aircraft reference. Therefore, checkout the *CSMR-2020* branch from the **Aircraft References** repo.

---

## Project Environment

For creating a **project environment** you have several options 🍟. Here we'll present the two mostly used ones (excluding the UNICADOworkflow on RCE stated [here](standalone.md)):

- Create a new folder for your project environment **or** use the folder where you have cloned the **Aircraft Design** repo. Both will be calles **project environment** in the following.

- In case you are **not** using the local copy itself as a **project environment**: Copy the tool(s) you want to execute / test (e.g. *initialSizing*) **AND** the folder `libs` from your local copy of **Aircraft Design** to your  **project environment**

- Inside your **project environment**, create the folders **Gnuplot** and **Inkscape**. Copy the **content** of the `bin/` from their installation directories to the newly created folders.

- Create a new folder **databases** inside your **project environment**

    - Inside **databases**, create a folder **airfoils**
            - From 'libs/airfoils', copy the folder F15 and NACA to the newly created **airfoils** directory
    - Inside **databases**, create a folder **engine**
            - From your **Engines** repo, copy the folder PW1127G-JM to the newly created **engine** directory

- Create a folder named **projects** within your **project environment**
    - Within your **projects** folder create a folder named as the aircraft class, e.g. CSMR
    - Within the **aircraft class** folder create a folder of the aircraft type, e.g. CSMR-2020
    - Copy the **content** (not the folder) of a specific design folder of the corresponding aircraft from your local copy of **Aircraft References** into the aircraft type folder. Options are
        - cleanSheetDesign,
        - retrofitDesign/aerodynamicCalibration,
        - retrofitDesign/engineCalibration and
        - retrofitDesign/withoutCalibration

    - Now you have again two options:
        - Test the tool on an empty aircraft exchange file: Delete the existing aircraft exchange file e.g. *CSMR-2020.xml*. Then rename the aircraft exchange file e.g. *CSMR-2020_startCSD.xml* to *CSMR-2020.xml* (if you have copied the cleanSheetDesign)
        - Test the tool on a so called converged aircraft: Directly execute your tool with the available aircraft exchange file, e.g. *CSMR-2020.xml*

If you made everything correctly, your folder structure inside your project environment will include at least following folders and files:

```
project environment
├── module_name/
│   ├── module_name.exe
│   └── module_name_config.xml
├── gnuplot/
│   ├── gnuplot.exe
│   └── ...
├── inkscape/
│   ├── inkscape.exe
│   └── ...
├── projects/
│   └──  CSMR/
│        └──CSMR-2020
│           ├── CSMR-2020.xml
│           └── Seat_positions.xml
├── databases/
│   ├── airfoils/
│   │   ├── NACA/
│   │   └── F15/
│   └── engine/
└── libs/
```

---

## Aircraft Design Tool Dependencies

Suppose you use an empty aircraft exchange file (described above in option 1).
The aircraft design tools have dependencies, e.g. a fuselage 🐳 has to exist in order to mount wings 🐦.  An aircraft geometry has to be available in order to conduct an aerodynamic analysis.

Therefore the tools can be executed based on their dependencies in the following sequence:

- initial_sizing
- create_mission_xml
- fuselage_design
- wing_design
- empennage_design
- tank_design
- propulsion_design
- landing_gear_design
- aerodynamic_analysis
- systems_design
- mission_analysis
- weight_and_balance_analysis
- performance_analysis
- cost_estimation
- ecological_assessment

!!! warning
    If you use a converged aircraft file (described above in option 2):
    Be aware that due to the module dependencies, there will probably be inconsistencies in the resulting aircraft file.
    After a single module execution, the aircraft will not be a valid configuration anymore.

---

## Tool execution

Finally we want to execute the tool. But what if we have noticed, that there are no executables in the tool folders? 🔥
Then the executables have first to be build inside the working copy e.g. of the **Aircraft Design** repo. Please follow the [build instructions](../developer/build/general.md).

If this is already done and an executable is present, then you can execute the respective tool from within the tool folder either on windows directly via double click or via a terminal e.g.

=== "cmd"

    ``` { .sh .copy }
    initialSizing.exe
    ```

=== "powershell"

    ``` { .sh .copy }
    initialSizing.exe
    ```
=== "git bash"

    ``` { .sh .copy }
    ./initialSizing.exe
    ```

If you want to examine the terminal outputs we've got you covered: `.log`-files are written for each tool (if not: activate `log_file_output` in the config file).

## Troubleshooting

The module throws an error? - Read the error message carefully.

- "Node not existing" / "File not found" or similar: Most probably either a file is missing in your project environment or some content within an file is lacking. Double check the description of the project environment and tool dependencies.
- "Can't open ...": If the file exist, make sure it is currently not used by another application.
- "ModuleNotFoundError: No Module named 'runmodule'": you try to execute a python tool which was not built correctly. Make sure to intall the python_packages before building the modudule. Go back to [build/python](../developer/build/python.md), follow the instruction and keep an eye on error messages during the build process.

## Video tutorial